==> haskell-dependent-sum-template-0.1.1.1-155-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-sum-template
version:              0.1.1.1
visibility:           public
id:                   dependent-sum-template-0.1.1.1-EnomJnXi94o4ruuSEDHbhN
key:                  dependent-sum-template-0.1.1.1-EnomJnXi94o4ruuSEDHbhN
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:
    Template Haskell code to generate instances of classes in dependent-sum package

description:
    Template Haskell code to generate instances of classes in dependent-sum package, such as '\''GEq'\'' and '\''GCompare'\''.

category:             Unclassified
abi:                  5b35a896f15cf63870a172f6c9fe9866
exposed:              True
exposed-modules:      Data.GADT.Compare.TH Data.GADT.Show.TH
hidden-modules:       Data.Dependent.Sum.TH.Internal
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/dependent-sum-template-0.1.1.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/dependent-sum-template-0.1.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum-template
hs-libraries:         HSdependent-sum-template-0.1.1.1-EnomJnXi94o4ruuSEDHbhN
depends:
    base-4.16.4.0 dependent-sum-0.7.2.0-2zeAnHFiZIlJATheKdYQ1m
    template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    th-extras-0.0.0.8-EdeMtD9sryUBOiRClmVaha

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum-template/html/dependent-sum-template.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum-template/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-sum-template-0.1.1.1-156-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-sum-template
version:              0.1.1.1
visibility:           public
id:                   dependent-sum-template-0.1.1.1-4J04orLj7EbLmaYezhED1Q
key:                  dependent-sum-template-0.1.1.1-4J04orLj7EbLmaYezhED1Q
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:
    Template Haskell code to generate instances of classes in dependent-sum package

description:
    Template Haskell code to generate instances of classes in dependent-sum package, such as '\''GEq'\'' and '\''GCompare'\''.

category:             Unclassified
abi:                  fed73904ffebc7e6821ac803202134f0
exposed:              True
exposed-modules:      Data.GADT.Compare.TH Data.GADT.Show.TH
hidden-modules:       Data.Dependent.Sum.TH.Internal
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/dependent-sum-template-0.1.1.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/dependent-sum-template-0.1.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum-template
hs-libraries:         HSdependent-sum-template-0.1.1.1-4J04orLj7EbLmaYezhED1Q
depends:
    base-4.16.4.0 dependent-sum-0.7.2.0-BvmDgdVDq2K1uj6wZTfVLG
    template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    th-extras-0.0.0.8-EdeMtD9sryUBOiRClmVaha

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum-template/html/dependent-sum-template.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum-template/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
